tensap.tensor\_algebra.tensors package
======================================

Submodules
----------

tensap.tensor\_algebra.tensors.canonical\_tensor module
-------------------------------------------------------

.. automodule:: tensap.tensor_algebra.tensors.canonical_tensor
   :members:
   :undoc-members:
   :show-inheritance:

tensap.tensor\_algebra.tensors.diagonal\_tensor module
------------------------------------------------------

.. automodule:: tensap.tensor_algebra.tensors.diagonal_tensor
   :members:
   :undoc-members:
   :show-inheritance:

tensap.tensor\_algebra.tensors.dimension\_tree module
-----------------------------------------------------

.. automodule:: tensap.tensor_algebra.tensors.dimension_tree
   :members:
   :undoc-members:
   :show-inheritance:

tensap.tensor\_algebra.tensors.full\_tensor module
--------------------------------------------------

.. automodule:: tensap.tensor_algebra.tensors.full_tensor
   :members:
   :undoc-members:
   :show-inheritance:

tensap.tensor\_algebra.tensors.sparse\_tensor module
----------------------------------------------------

.. automodule:: tensap.tensor_algebra.tensors.sparse_tensor
   :members:
   :undoc-members:
   :show-inheritance:

tensap.tensor\_algebra.tensors.tree\_based\_tensor module
---------------------------------------------------------

.. automodule:: tensap.tensor_algebra.tensors.tree_based_tensor
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tensap.tensor_algebra.tensors
   :members:
   :undoc-members:
   :show-inheritance:
